@@ -23,12 +23,10 @@ package cmd
 import (
 	"encoding/json"
 	"errors"
-	"os"
+	"fmt"
 	"syscall"
 
 	"github.com/fatih/color"
-	"github.com/sirupsen/logrus"
-	"github.com/spf13/afero"
 	"github.com/spf13/cobra"
 	"golang.org/x/term"
 	"gopkg.in/guregu/null.v3"
@@ -39,7 +37,7 @@ import (
 )
 
 //nolint:funlen,gocognit
-func getLoginCloudCommand(logger logrus.FieldLogger, globalFlags *commandFlags) *cobra.Command {
+func getCmdLoginCloud(globalState *globalState) *cobra.Command {
 	// loginCloudCommand represents the 'login cloud' command
 	loginCloudCommand := &cobra.Command{
 		Use:   "cloud",
@@ -58,9 +56,7 @@ This will set the default token used when just "k6 run -o cloud" is passed.`,
   k6 login cloud`[1:],
 		Args: cobra.NoArgs,
 		RunE: func(cmd *cobra.Command, args []string) error {
-			fs := afero.NewOsFs()
-
-			currentDiskConf, configPath, err := readDiskConfig(fs, globalFlags)
+			currentDiskConf, err := readDiskConfig(globalState)
 			if err != nil {
 				return err
 			}
@@ -77,7 +73,7 @@ This will set the default token used when just "k6 run -o cloud" is passed.`,
 			// We want to use this fully consolidated config for things like
 			// host addresses, so users can overwrite them with env vars.
 			consolidatedCurrentConfig, err := cloudapi.GetConsolidatedConfig(
-				currentJSONConfigRaw, buildEnvMap(os.Environ()), "", nil)
+				currentJSONConfigRaw, globalState.envVars, "", nil)
 			if err != nil {
 				return err
 			}
@@ -91,7 +87,7 @@ This will set the default token used when just "k6 run -o cloud" is passed.`,
 			switch {
 			case reset.Valid:
 				newCloudConf.Token = null.StringFromPtr(nil)
-				fprintf(globalFlags.stdout, "  token reset\n")
+				printToStdout(globalState, "  token reset\n")
 			case show.Bool:
 			case token.Valid:
 				newCloudConf.Token = token
@@ -109,10 +105,10 @@ This will set the default token used when just "k6 run -o cloud" is passed.`,
 					},
 				}
 				if !term.IsTerminal(int(syscall.Stdin)) { // nolint: unconvert
-					logger.Warn("Stdin is not a terminal, falling back to plain text input")
+					globalState.logger.Warn("Stdin is not a terminal, falling back to plain text input")
 				}
 				var vals map[string]string
-				vals, err = form.Run(os.Stdin, globalFlags.stdout)
+				vals, err = form.Run(globalState.stdIn, globalState.stdOut)
 				if err != nil {
 					return err
 				}
@@ -120,7 +116,7 @@ This will set the default token used when just "k6 run -o cloud" is passed.`,
 				password := vals["Password"]
 
 				client := cloudapi.NewClient(
-					logger,
+					globalState.logger,
 					"",
 					consolidatedCurrentConfig.Host.String,
 					consts.Version,
@@ -146,13 +142,18 @@ This will set the default token used when just "k6 run -o cloud" is passed.`,
 			if err != nil {
 				return err
 			}
-			if err := writeDiskConfig(fs, configPath, currentDiskConf); err != nil {
+			if err := writeDiskConfig(globalState, currentDiskConf); err != nil {
 				return err
 			}
 
 			if newCloudConf.Token.Valid {
-				valueColor := getColor(globalFlags.noColor || !globalFlags.stdoutTTY, color.FgCyan)
-				fprintf(globalFlags.stdout, "  token: %s\n", valueColor.Sprint(newCloudConf.Token.String))
+				valueColor := getColor(globalState.flags.noColor || !globalState.stdOut.isTTY, color.FgCyan)
+				if !globalState.flags.quiet {
+					printToStdout(globalState, fmt.Sprintf("  token: %s\n", valueColor.Sprint(newCloudConf.Token.String)))
+				}
+				printToStdout(globalState, fmt.Sprintf(
+					"Logged in successfully, token saved in %s\n", globalState.flags.configFilePath,
+				))
 			}
 			return nil
 		},
