@@ -22,19 +22,21 @@
 //nolint: golint
 package exitcodes
 
-import "go.k6.io/k6/errext"
+// ExitCode is just a type representing a process exit code for k6
+type ExitCode uint8
 
+// list of exit codes used by k6
 const (
-	CloudTestRunFailed       errext.ExitCode = 97 // This used to be 99 before k6 v0.33.0
-	CloudFailedToGetProgress errext.ExitCode = 98
-	ThresholdsHaveFailed     errext.ExitCode = 99
-	SetupTimeout             errext.ExitCode = 100
-	TeardownTimeout          errext.ExitCode = 101
-	GenericTimeout           errext.ExitCode = 102 // TODO: remove?
-	GenericEngine            errext.ExitCode = 103
-	InvalidConfig            errext.ExitCode = 104
-	ExternalAbort            errext.ExitCode = 105
-	CannotStartRESTAPI       errext.ExitCode = 106
-	ScriptException          errext.ExitCode = 107
-	ScriptAborted            errext.ExitCode = 108
+	CloudTestRunFailed       ExitCode = 97 // This used to be 99 before k6 v0.33.0
+	CloudFailedToGetProgress ExitCode = 98
+	ThresholdsHaveFailed     ExitCode = 99
+	SetupTimeout             ExitCode = 100
+	TeardownTimeout          ExitCode = 101
+	GenericTimeout           ExitCode = 102 // TODO: remove?
+	GenericEngine            ExitCode = 103
+	InvalidConfig            ExitCode = 104
+	ExternalAbort            ExitCode = 105
+	CannotStartRESTAPI       ExitCode = 106
+	ScriptException          ExitCode = 107
+	ScriptAborted            ExitCode = 108
 )
