@@ -30,7 +30,9 @@ import (
 )
 
 //go:generate go run gen/gen_elements.go
+//go:generate gofumpt -w .
 
+//nolint:gochecknoglobals
 var defaultPorts = map[string]string{
 	"http":  "80",
 	"https": "443",
@@ -98,15 +100,12 @@ const (
 //revive:disable:exported
 
 type (
-	HrefElement         struct{ Element }
-	MediaElement        struct{ Element }
-	FormFieldElement    struct{ Element }
-	ModElement          struct{ Element }
-	TableSectionElement struct{ Element }
-	TableCellElement    struct{ Element }
-)
-
-type (
+	HrefElement            struct{ Element }
+	MediaElement           struct{ Element }
+	FormFieldElement       struct{ Element }
+	ModElement             struct{ Element }
+	TableSectionElement    struct{ Element }
+	TableCellElement       struct{ Element }
 	AnchorElement          struct{ HrefElement }
 	AreaElement            struct{ HrefElement }
 	AudioElement           struct{ MediaElement }
@@ -247,7 +246,6 @@ func (h HrefElement) Password() string {
 	return pwd
 }
 
-// nolint: goconst
 func (h HrefElement) Origin() string {
 	href := h.hrefURL()
 
@@ -330,7 +328,6 @@ func (f FormFieldElement) FormAction() string {
 	return actionURL.String()
 }
 
-// nolint: goconst
 func (f FormFieldElement) FormEnctype() string {
 	enctype, _ := f.formOrElemAttr("enctype")
 
@@ -425,11 +422,10 @@ func (f FormElement) Method() string {
 	return methodGet
 }
 
-// nolint: goconst
 func (i InputElement) List() goja.Value {
-	listId := i.attrAsString("list")
+	listID := i.attrAsString("list")
 
-	if listId == "" {
+	if listID == "" {
 		return goja.Undefined()
 	}
 
@@ -446,7 +442,7 @@ func (i InputElement) List() goja.Value {
 		return goja.Undefined()
 	}
 
-	datalist := i.sel.sel.Parents().Last().Find("datalist[id=\"" + listId + "\"]")
+	datalist := i.sel.sel.Parents().Last().Find("datalist[id=\"" + listID + "\"]")
 	if datalist.Length() == 0 {
 		return goja.Undefined()
 	}
@@ -532,12 +528,12 @@ func (o OptionElement) Form() goja.Value {
 	}
 
 	prtSelect := o.sel.sel.ParentsFiltered("select")
-	formId, exists := prtSelect.Attr("form")
+	formID, exists := prtSelect.Attr("form")
 	if !exists {
 		return goja.Undefined()
 	}
 
-	ownerForm := prtSelect.Parents().Last().Find("form#" + formId)
+	ownerForm := prtSelect.Parents().Last().Find("form#" + formID)
 	if ownerForm.Length() == 0 {
 		return goja.Undefined()
 	}
@@ -661,17 +657,15 @@ func (s SelectElement) SelectedOptions() []goja.Value {
 func (s SelectElement) Size() int {
 	if s.attrIsPresent("multiple") {
 		return 4
-	} else {
-		return 1
 	}
+	return 1
 }
 
 func (s SelectElement) Type() string {
 	if s.attrIsPresent("multiple") {
 		return "select-multiple"
-	} else {
-		return "select"
 	}
+	return "select"
 }
 
 func (s SelectElement) Value() string {
