@@ -73,6 +73,7 @@ func TestSampleToRow(t *testing.T) {
 		sample      *metrics.Sample
 		resTags     []string
 		ignoredTags []string
+		timeFormat  string
 	}{
 		{
 			testname: "One res tag, one ignored tag, one extra tag",
@@ -88,6 +89,7 @@ func TestSampleToRow(t *testing.T) {
 			},
 			resTags:     []string{"tag1"},
 			ignoredTags: []string{"tag2"},
+			timeFormat:  "unix",
 		},
 		{
 			testname: "Two res tags, three extra tags",
@@ -105,9 +107,10 @@ func TestSampleToRow(t *testing.T) {
 			},
 			resTags:     []string{"tag1", "tag2"},
 			ignoredTags: []string{},
+			timeFormat:  "unix",
 		},
 		{
-			testname: "Two res tags, two ignored",
+			testname: "Two res tags, two ignored, with RFC3339 timestamp",
 			sample: &metrics.Sample{
 				Time:   time.Unix(1562324644, 0),
 				Metric: testMetric,
@@ -123,6 +126,7 @@ func TestSampleToRow(t *testing.T) {
 			},
 			resTags:     []string{"tag1", "tag3"},
 			ignoredTags: []string{"tag4", "tag6"},
+			timeFormat:  "rfc3339",
 		},
 	}
 
@@ -158,7 +162,7 @@ func TestSampleToRow(t *testing.T) {
 		{
 			baseRow: []string{
 				"my_metric",
-				"1562324644",
+				time.Unix(1562324644, 0).Format(time.RFC3339),
 				"1.000000",
 				"val1",
 				"val3",
@@ -173,10 +177,12 @@ func TestSampleToRow(t *testing.T) {
 	for i := range testData {
 		testname, sample := testData[i].testname, testData[i].sample
 		resTags, ignoredTags := testData[i].resTags, testData[i].ignoredTags
+		timeFormat, err := TimeFormatString(testData[i].timeFormat)
+		require.NoError(t, err)
 		expectedRow := expected[i]
 
 		t.Run(testname, func(t *testing.T) {
-			row := SampleToRow(sample, resTags, ignoredTags, make([]string, 3+len(resTags)+1))
+			row := SampleToRow(sample, resTags, ignoredTags, make([]string, 3+len(resTags)+1), timeFormat)
 			for ind, cell := range expectedRow.baseRow {
 				assert.Equal(t, cell, row[ind])
 			}
@@ -225,6 +231,7 @@ func TestRun(t *testing.T) {
 		samples        []metrics.SampleContainer
 		fileName       string
 		fileReaderFunc func(fileName string, fs afero.Fs) string
+		timeFormat     string
 		outputContent  string
 	}{
 		{
@@ -253,6 +260,7 @@ func TestRun(t *testing.T) {
 			},
 			fileName:       "test",
 			fileReaderFunc: readUnCompressedFile,
+			timeFormat:     "",
 			outputContent:  "metric_name,timestamp,metric_value,check,error,extra_tags\n" + "my_metric,1562324643,1.000000,val1,val3,url=val2\n" + "my_metric,1562324644,1.000000,val1,val3,tag4=val4&url=val2\n",
 		},
 		{
@@ -281,30 +289,73 @@ func TestRun(t *testing.T) {
 			},
 			fileName:       "test.gz",
 			fileReaderFunc: readCompressedFile,
+			timeFormat:     "unix",
 			outputContent:  "metric_name,timestamp,metric_value,check,error,extra_tags\n" + "my_metric,1562324643,1.000000,val1,val3,url=val2\n" + "my_metric,1562324644,1.000000,val1,val3,name=val4&url=val2\n",
 		},
+		{
+			samples: []metrics.SampleContainer{
+				metrics.Sample{
+					Time:   time.Unix(1562324644, 0),
+					Metric: testMetric,
+					Value:  1,
+					Tags: metrics.NewSampleTags(map[string]string{
+						"check": "val1",
+						"url":   "val2",
+						"error": "val3",
+					}),
+				},
+				metrics.Sample{
+					Time:   time.Unix(1562324644, 0),
+					Metric: testMetric,
+					Value:  1,
+					Tags: metrics.NewSampleTags(map[string]string{
+						"check": "val1",
+						"url":   "val2",
+						"error": "val3",
+						"name":  "val4",
+					}),
+				},
+			},
+			fileName:       "test",
+			fileReaderFunc: readUnCompressedFile,
+			timeFormat:     "rfc3339",
+			outputContent: "metric_name,timestamp,metric_value,check,error,extra_tags\n" +
+				"my_metric," + time.Unix(1562324644, 0).Format(time.RFC3339) + ",1.000000,val1,val3,url=val2\n" +
+				"my_metric," + time.Unix(1562324644, 0).Format(time.RFC3339) + ",1.000000,val1,val3,name=val4&url=val2\n",
+		},
 	}
 
-	for _, data := range testData {
-		mem := afero.NewMemMapFs()
-		output, err := newOutput(output.Params{
-			Logger:         testutils.NewLogger(t),
-			FS:             mem,
-			ConfigArgument: data.fileName,
-			ScriptOptions: lib.Options{
-				SystemTags: metrics.NewSystemTagSet(metrics.TagError | metrics.TagCheck),
-			},
+	for i, data := range testData {
+		name := fmt.Sprint(i)
+		data := data
+		t.Run(name, func(t *testing.T) {
+			t.Parallel()
+			mem := afero.NewMemMapFs()
+			env := make(map[string]string)
+			if data.timeFormat != "" {
+				env["K6_CSV_TIME_FORMAT"] = data.timeFormat
+			}
+
+			output, err := newOutput(output.Params{
+				Logger:         testutils.NewLogger(t),
+				FS:             mem,
+				Environment:    env,
+				ConfigArgument: data.fileName,
+				ScriptOptions: lib.Options{
+					SystemTags: metrics.NewSystemTagSet(metrics.TagError | metrics.TagCheck),
+				},
+			})
+			require.NoError(t, err)
+			require.NotNil(t, output)
+
+			require.NoError(t, output.Start())
+			output.AddMetricSamples(data.samples)
+			time.Sleep(1 * time.Second)
+			require.NoError(t, output.Stop())
+
+			finalOutput := data.fileReaderFunc(data.fileName, mem)
+			assert.Equal(t, data.outputContent, sortExtraTagsForTest(t, finalOutput))
 		})
-		require.NoError(t, err)
-		require.NotNil(t, output)
-
-		require.NoError(t, output.Start())
-		output.AddMetricSamples(data.samples)
-		time.Sleep(1 * time.Second)
-		require.NoError(t, output.Stop())
-
-		finalOutput := data.fileReaderFunc(data.fileName, mem)
-		assert.Equal(t, data.outputContent, sortExtraTagsForTest(t, finalOutput))
 	}
 }
 
