@@ -28,7 +28,7 @@ import (
 	"strings"
 	"time"
 
-	"github.com/kelseyhightower/envconfig"
+	"github.com/mstoykov/envconfig"
 	"gopkg.in/guregu/null.v3"
 
 	"go.k6.io/k6/lib/types"
@@ -199,7 +199,10 @@ func GetConsolidatedConfig(jsonRawConf json.RawMessage, env map[string]string, u
 	}
 
 	envConfig := Config{}
-	if err := envconfig.Process("", &envConfig); err != nil {
+	if err := envconfig.Process("", &envConfig, func(key string) (string, bool) {
+		v, ok := env[key]
+		return v, ok
+	}); err != nil {
 		// TODO: get rid of envconfig and actually use the env parameter...
 		return result, err
 	}
